@@ -146,9 +146,12 @@ struct StringBase : public AST {
 };
 
 struct Step : public StringBase {
-    Step (EvalState *ev) : StringBase (ev), any_node (false), is_attr (false) {}
+    Step (EvalState *ev, bool context=false)
+     : StringBase (ev),
+       any_node (false), context_node (context), is_attr (false) {}
     Step (EvalState *ev, const char *s, const char *e, bool isattr=false)
-     : StringBase (ev, s, e), any_node (string == "*"), is_attr (isattr) {}
+     : StringBase (ev, s, e),
+       any_node (string == "*"), context_node (false), is_attr (isattr) {}
 
     bool matches (Node *n);
     bool matches (Attribute *a);
@@ -157,13 +160,15 @@ struct Step : public StringBase {
 #ifdef KMPLAYER_EXPR_DEBUG
     virtual void dump () const {
         fprintf (stderr, "Step %c%s",
-                is_attr ? '@' : ' ', (const char *) string);
+                is_attr ? '@' : ' ',
+                context_node ? "." : (const char *) string);
         AST::dump();
     }
 #endif
 
     TrieString attr;
     bool any_node;
+    bool context_node;
     bool is_attr;
 };
 
@@ -200,6 +205,12 @@ struct StringLiteral : public StringBase {
 #endif
 };
 
+struct Contains : public BoolBase {
+    Contains (EvalState *ev) : BoolBase (ev) {}
+
+    virtual bool toBool () const;
+};
+
 struct Not : public BoolBase {
     Not (EvalState *ev) : BoolBase (ev) {}
 
@@ -266,6 +277,12 @@ struct CurrentDate : public StringBase {
     virtual String toString () const;
 };
 
+struct EscapeUri : public StringBase {
+    EscapeUri (EvalState *ev) : StringBase (ev) {}
+
+    virtual String toString () const;
+};
+
 struct Sort : public AST {
     Sort (EvalState *ev) : AST (ev) {}
 
@@ -576,6 +593,9 @@ void Identifier::childByStep (Step *step, bool recurse) const {
             if (recurse)
                 for (Node *c = n->firstChild(); c; c = c->nextSibling ())
                     recursive_lst.append (new NodeValueItem (c));
+        } else if (step->context_node) {
+            if (eval_state->parent)
+                lst->append (new NodeValueItem (eval_state->parent->root));
         } else {
             for (Node *c = n->firstChild(); c; c = c->nextSibling ()) {
                 if (step->matches (c))
@@ -662,6 +682,19 @@ AST::Type StringLiteral::type () const {
     return TString;
 }
 
+bool Contains::toBool () const {
+    if (eval_state->sequence != sequence) {
+        sequence = eval_state->sequence;
+        b = false;
+        if (first_child) {
+            AST *s = first_child->next_sibling;
+            if (s)
+                b = first_child->toString ().indexOf (s->toString ()) > -1;
+        }
+    }
+    return b;
+}
+
 bool Not::toBool () const {
     if (eval_state->sequence != sequence) {
         sequence = eval_state->sequence;
@@ -768,6 +801,16 @@ String Concat::toString () const {
     return string;
 }
 
+String EscapeUri::toString () const {
+    if (eval_state->sequence != sequence) {
+        sequence = eval_state->sequence;
+        string.clear ();
+        if (first_child)
+            string = URL::encode_string (first_child->toString ());
+    }
+    return string;
+}
+
 String StringJoin::toString () const {
     if (eval_state->sequence != sequence) {
         sequence = eval_state->sequence;
@@ -1144,7 +1187,8 @@ static bool parseLiteral (const char *str, const char **end, AST *ast) {
             }
             *end = s;
         }
-        if (*end && (!sign || *end > str) && *end - str < 64) {
+        if (*end && (!sign || *end > str) && *end - str < 64 &&
+                (!decimal || *end > str)) {
             char buf[64];
             ++(*end);
             memcpy (buf, str, *end - str);
@@ -1167,7 +1211,15 @@ static bool parseStep (const char *str, const char **end, AST *ast) {
 #endif
     Step *entry = NULL;
     const char *s = str;
-    if (*s == '/') {
+    if (*s == '.') {
+        ++s;
+        if (s && *s == '.') { // TODO
+            entry = new Step (ast->eval_state, true);
+            ++s;
+        } else {
+            entry = new Step (ast->eval_state, true);
+        }
+    } else if (*s == '/') {
         entry = new Step (ast->eval_state);
     } else {
         bool is_attr = *s == '@';
@@ -1200,6 +1252,9 @@ static bool parseStep (const char *str, const char **end, AST *ast) {
     if (entry) {
         appendASTChild (ast, entry);
         *end = s;
+#ifdef KMPLAYER_EXPR_DEBUG
+        fprintf (stderr, "%s success end:'%s'\n", __FUNCTION__, *end);
+#endif
         return true;
     }
     return false;
@@ -1299,6 +1354,8 @@ static bool parseFunction (const char *str, const char **end, AST *ast) {
                 AST *func = NULL;
                 if (name == "concat")
                     func = new Concat (ast->eval_state);
+                else if (name == "contains")
+                    func = new Contains (ast->eval_state);
                 else if (name == "hours-from-time")
                     func = new HoursFromTime (ast->eval_state);
                 else if (name == "minutes-from-time")
@@ -1321,6 +1378,8 @@ static bool parseFunction (const char *str, const char **end, AST *ast) {
                     func = new Sort (ast->eval_state);
                 else if (name == "string-join")
                     func = new StringJoin (ast->eval_state);
+                else if (name == "escape-uri")
+                    func = new EscapeUri (ast->eval_state);
                 else
                     return false;
                 appendASTChild (ast, func);
