@@ -270,8 +270,6 @@ static void stateChangeMessage (GstObject *src, GstState os,  GstState ns)
                         if (!has_video_codec)
                             output ("Video: no video\n");
                         output ("\rA:0.0\rA:0.0");
-                        if (seek_start > 0)
-                            seek (seek_start * 10, 1);
                     } else {
                         output ("\rCache fill: 100%");
                     }
@@ -288,6 +286,10 @@ static void stateChangeMessage (GstObject *src, GstState os,  GstState ns)
                     else
                         output ("ID_PAUSED\n");
                 } else if (StatePlaying == transition_state) {
+                    if (seek_start > 0) {
+                        seek (seek_start * 10, 1);
+                        seek_start = 0;
+                    }
                     gst_element_set_state (gst_elm_play, GST_STATE_PLAYING);
                 }
             }
@@ -575,10 +577,9 @@ static void play () {
         gst_x_overlay_set_xwindow_id (xoverlay, wid);
     }
     /*g_signal_connect (content, "expose-event", G_CALLBACK (cb_expose), videosink );*/
-    gst_element_set_bus (videosink, gst_bus);
-    gst_element_set_state (videosink, GST_STATE_READY);
+    gst_element_set_bus (bin, gst_bus);
     gst_element_set_state (bin, GST_STATE_READY);
-    success = gstPollForStateChange (videosink, GST_STATE_READY, GST_SECOND/2);
+    success = gstPollForStateChange (bin, GST_STATE_READY, GST_SECOND/2);
     /*if (!success) {
         / * Drop this video sink * /
         gst_element_set_state (videosink, GST_STATE_NULL);
