@@ -81,6 +81,7 @@ typedef struct _Application {
     GtkWidget *video_up;
     GtkWidget *video_down;
     GtkWidget *zoom_box;
+    GtkWidget *aspects_toggle;
     GtkWidget *panzoom_toggle;
     GtkWidget * playlist_view;
     GtkWidget * downloads_view;
@@ -116,6 +117,9 @@ typedef struct _Application {
     bool top_most_window;
     bool show_playlist;
     bool show_progress;
+    bool aspects_ignored;
+    bool zoom_enabled;
+    bool in_ui_update;
 } Application;
 
 GtkWidget * createTreeView (Application * app);
