@@ -37,9 +37,6 @@ const short id_node_media_group = 306;
 const short id_node_media_content = 307;
 const short id_node_media_title = 308;
 const short id_node_media_description = 309;
-const short id_node_media_player = 310;
-const short id_node_media_thumbnail = 311;
-const short id_node_gd_rating = 312;
 const short id_node_ignored = 313;
 
 /**
@@ -84,9 +81,9 @@ class KMPLAYER_NO_EXPORT MediaGroup : public Element {
 public:
     MediaGroup (NodePtr &d) : Element (d, id_node_media_group) {}
     Node *childFromTag (const String &tag);
+    void closed ();
     void message (MessageType msg, void *content=NULL);
     KDE_NO_EXPORT const char *nodeName () const { return "media:group"; }
-    void addSummary (Node *parent, Node *ratings);
 };
 
 class KMPLAYER_NO_EXPORT MediaContent : public Mrl {
