@@ -187,6 +187,7 @@ void Playlist::show (View *view)
         deleteAuxiliaries (this);
     if (view->show) {
         TrieString aspect_ratio ("aspectRatio");
+        TrieString player ("player");
         Node *before = NULL;
         if (!view->before)
             view->before = evaluateExpr (view->getAttribute ("before"));
@@ -219,6 +220,7 @@ void Playlist::show (View *view)
                     if (a->name () == Ids::attr_url ||
                             a->name () == Ids::attr_title ||
                             a->name () == Ids::attr_panzoom ||
+                            a->name () == player ||
                             a->name () == aspect_ratio)
                         attrs.append (new Attribute (TrieString (),
                                     a->name (), a->value ()));
