@@ -1503,7 +1503,7 @@ void save_locationbar (Application *app) {
     GtkTreeModel * model = GTK_TREE_MODEL (gtk_combo_box_get_model (
                 GTK_COMBO_BOX (app->location_bar)));
     for (bool b = gtk_tree_model_get_iter_first (model, &iterator);
-            b;
+            b && idx < 7;
             b = gtk_tree_model_iter_next (model, &iterator)) {
         GValue value = { 0 , };
         gtk_tree_model_get_value (model, &iterator, 0, &value);
