@@ -634,14 +634,25 @@ KMPLAYER_NO_EXPORT bool MPlayer::brightness (int pos, bool absolute) {
 
 bool MPlayer::calculateScale (int &x, int &y, int &w, int &h)
 {
-    // TODO vertical scale
-    x = 0;
-    h = stream_width * 480 / 800;
-    if (h < 0)
-        return false;
-    y = (stream_height - h) / 2;
-    w = stream_width;
-    return true;
+    if (stream_width > 0 && stream_height > 0) {
+        if ((1.0 * stream_height) / stream_width > 0.6) {
+            x = 0;
+            h = stream_width * 480 / 800;
+            if (h <= 0)
+                return false;
+            y = (stream_height - h) / 2;
+            w = stream_width;
+        } else {
+            y = 0;
+            w = stream_height * 800 / 480;
+            if (w <= 0)
+                return false;
+            x = (stream_width - w) / 2;
+            h = stream_height;
+        }
+        return true;
+    }
+    return false;
 }
 
 void MPlayer::toggleScale ()
