@@ -401,8 +401,14 @@ KMPLAYER_NO_EXPORT void NpStream::close () {
 
 KMPLAYER_NO_EXPORT void NpStream::jobData (IOJob *jb, ByteArray & data) {
     //debugLog () << "NpStream::jobData " << url.url () << endl;
-    if (!bytes)
+    if (!bytes) {
         nppStreamInfo (stream, jb->contentType (), jb->contentLength ());
+        if (data.size () > 2 &&
+                data.data ()[0] == 'F' &&
+                data.data ()[1] == 'L' &&
+                data.data ()[2] == 'V')
+            output ("ID_REF=%s\n", (const char *) url.url ());
+    }
     bytes += data.size ();
     nppStreamData (stream, data.data (), data.size (), NULL /*FIXME*/);
 }
@@ -556,7 +562,7 @@ static void sig_abort(int i) {
     if (!n)
         return;
     backtrace_symbols_fd (trace, n, 2);
-    exit(0);
+    _exit(0);
 }
 
 
