@@ -67,6 +67,7 @@ public:
     unsigned long videoXId () const;
     Mrl *videoMrl () { return video_node ? video_node->mrl () : NULL; }
     void setOutputWidget (Application *, GtkWidget * w);
+    void toggleUseAspects () { m_use_aspects = !m_use_aspects; }
 private:
     void syncVisual (const IRect & rect);
     void updateSurfaceBounds ();
@@ -91,6 +92,7 @@ private:
     bool m_event_filter_on;
     bool m_updaters_enabled;
     bool m_video_filter;
+    bool m_use_aspects;
 };
 
 } // namespace KMPlayer
